# Changelog

**23.5.6**
* Updated project readme
* Updated package readme template
* Added UNIX script for local setup

**23.5.5**
* Django 4.2
* Linter updates

**23.5.4**
* Improved documentation
* Added further code quality templates

**23.5.3**
* Improved rendered readme file

**23.5.2**
* Templates render a trailing newline (to conform with Python linting)

**23.5.1**
* Initial release
